@@ -25,6 +25,7 @@ import glob
 import shutil
 from time import sleep
 from calculate.core.server.func import MethodsInterface
+from calculate.core.server.admin import Admins
 from calculate.lib.utils.files import (pathJoin,
                                        isMount, process, listDirectory,
                                        checkUtils, readFile, find, copyWithPath,
@@ -550,7 +551,9 @@ class Install(MethodsInterface):
         установка пароля пользователя root
         """
         migrator = migrate(target.getDirectory())
-        if not migrator.migrate(migrate_data, root_pwd, [], [], ):
+
+        if not migrator.migrate([[x[0],x[2],x[3]] for x in migrate_data],
+                                root_pwd, [], [], ):
             raise InstallError(_("Failed to migrate users onto the new system"))
         return True
 
@@ -572,6 +575,19 @@ class Install(MethodsInterface):
             shutil.move(fn, new_name)
         return True
 
+    def update_admin_ini(self):
+        """
+        Обновить список локальных администраторов при установке
+        """
+        install_admin = Admins(self.clVars, chroot=True)
+        install_admin.clear()
+        for k,v in self.clVars.select('install.cl_migrate_user',
+                                      'install.cl_migrate_admin',
+                                      install_cl_migrate_admin__ne="none"):
+            install_admin[k] = v
+            install_admin.save()
+        return True
+
     def init_themes(self):
         self.clVars.Get('cl_splash_image_hash')
         self.clVars.Get('cl_grub_image_hash')
