@@ -30,9 +30,12 @@ from calculate.lib.utils.common import getValueFromConfig, getValueFromCmdLine
 from calculate.lib.utils.common import getUserPrimaryGroup
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.device import getUdevDeviceInfo
+from calculate.lib.encrypt import sha256_crypt
+from calculate.core.server.admin import Admins
 from calculate.lib.variables.system import RootType
 from autopartition import SchemeOpt, SchemeDevices
 from calculate.lib.encrypt import get_shadow_hash, get_grub_hash
+from calculate.core.server.admin import Admins
 import calculate.lib.cl_ini_parser as cl_ini_parser
 
 from calculate.lib.cl_lang import setLocalTranslate, _
@@ -295,21 +298,33 @@ class VariableClMigrateData(UserHelper, TableVariable):
     """
     type = 'table'
     opt = ["--user", "-u"]
-    metavalue = 'USER[:GROUPS]'
-    source = ['cl_migrate_user', 'cl_migrate_user_groups',
+    metavalue = 'USER[:ADMIN[:GROUPS]]'
+    source = ['cl_migrate_user', 'cl_migrate_admin',
+              'cl_migrate_user_groups',
               'cl_migrate_user_pwd']
     untrusted = True
 
     def init(self):
-        self.help = _("add a user to the installed system")
+        self.help = _("add a user to the installed system. USER is username. "
+                      "ADMIN is administrator rights (none, all, update, "
+                      "none by default). "
+                      "GROUPS is list user supplimentary groups "
+                      "(comma delimeter). "
+                      "Use 'none' value to discard user migration")
         self.label = _("Migrating users")
 
+    def set(self, value):
+        if len(value) == 1:
+            if len(value[0]) > 1 and value[0][0] == 'none':
+                return [[]]
+        return value
+
 
 class VariableClMigrateDataBrief(UserHelper, TableVariable):
     """
     User migrate data table for brief view
     """
-    source = ['cl_migrate_user', 'cl_migrate_user_groups']
+    source = ['cl_migrate_user', 'cl_migrate_admin', 'cl_migrate_user_groups']
 
     def init(self):
         self.label = _("Migrating users")
@@ -322,7 +337,7 @@ class VariableClMigrateUser(UserHelper, Variable):
     type = 'list'
 
     def init(self):
-        self.label = _("Users")
+        self.label = _("User")
 
     def get(self):
         """
@@ -330,6 +345,44 @@ class VariableClMigrateUser(UserHelper, Variable):
         """
         return filter("root".__ne__, getPasswdUsers())
 
+    def check(self, value):
+        """
+        Проверка на корректное имя пользователя
+        """
+        if any(not x for x in value):
+            raise VariableError(_("Username is missing"))
+
+
+class VariableClMigrateAdmin(UserHelper, Variable):
+    """
+    Migrate users list
+    """
+    type = 'choice-list'
+    default_value = "none"
+
+    def init(self):
+        self.label = _("Administrator")
+
+    def choice(self):
+        return [
+            ("none", ""),
+            ("all", _("Full access"))
+            ("update", _("System update")),
+        ]
+
+    def get(self):
+        """
+        Migrating users (users above 1000 uid)
+        """
+        admins = Admins(self.parent)
+        return [admins[x] or self.default_value
+                for x in self.Get('cl_migrate_user')]
+
+    def set(self, value):
+        name_map = {'update':'system_update'}
+        value = map(lambda x:name_map.get(x,x), value)
+        return map(lambda x: x if x else self.default_value, value)
+
 
 class VariableClMigrateUserGroups(UserHelper, Variable):
     """
@@ -406,7 +459,11 @@ class VariableClMigrateUserPwd(UserHelper, Variable):
                         userData = filter(lambda x: x[0] == userName,
                                           shadowData)
                         hashPwd = userData[0][1]
-                        retList.append(hashPwd)
+                        if (sha256_crypt.identify(hashPwd) and
+                            sha256_crypt.verify("guest", hashPwd)):
+                            retList.append("")
+                        else:
+                            retList.append(hashPwd)
                     else:
                         retList.append("")
         return retList
